@@ -1,19 +1,39 @@
 import pathlib
 import sys
 from pathlib import Path
-from typing import List, Optional
+from typing import Optional
 
 import typer
-from typer import Option
+
+from robotoff.types import ObjectDetectionModel, PredictionType, WorkerQueue
 
 app = typer.Typer()
 
 
 @app.command()
-def run(service: str) -> None:
-    from robotoff.cli.run import run as run_
+def run_scheduler():
+    """Launch the scheduler service."""
+    from robotoff import scheduler
+    from robotoff.utils import get_logger
 
-    run_(service)
+    # Defining a root logger
+    get_logger()
+    scheduler.run()
+
+
+@app.command()
+def run_worker(
+    queues: list[WorkerQueue] = typer.Argument(
+        ..., help="Names of the queues to listen to"
+    ),
+    burst: bool = typer.Option(
+        False, help="Run in burst mode (quit after all work is done)"
+    ),
+):
+    """Launch a worker."""
+    from robotoff.workers.main import run
+
+    run(queues=[x.value for x in queues], burst=burst)
 
 
 @app.command()
@@ -23,11 +43,12 @@ def regenerate_ocr_insights(
     """Regenerate OCR predictions/insights for a specific product and import
     them."""
     from robotoff import settings
+    from robotoff.insights import importer
     from robotoff.insights.extraction import (
         DEFAULT_OCR_PREDICTION_TYPES,
         extract_ocr_predictions,
     )
-    from robotoff.insights.importer import import_insights as import_insights_
+    from robotoff.models import db
     from robotoff.off import generate_json_ocr_url
     from robotoff.products import get_product
     from robotoff.utils import get_logger
@@ -48,41 +69,33 @@ def regenerate_ocr_insights(
             barcode, ocr_url, DEFAULT_OCR_PREDICTION_TYPES
         )
 
-    imported = import_insights_(predictions, settings.OFF_SERVER_DOMAIN)
-    logger.info(f"Import finished, {imported} insights imported")
+    with db:
+        imported = importer.import_insights(predictions, settings.OFF_SERVER_DOMAIN)
+
+    logger.info("Import finished, %s insights imported", imported)
 
 
 @app.command()
-def generate_ocr_insights(
-    source: str,
-    prediction_type: str,
-    output: Path = Option(
-        ...,
-        help="File to write output to, stdout if not specified",
+def generate_ocr_predictions(
+    input_path: Path = typer.Argument(
+        ..., help="Path to a (gzipped-)OCR JSONL archive"
+    ),
+    prediction_type: PredictionType = typer.Argument(
+        ..., help="Type of the predictions to generate (label, brand,...)"
+    ),
+    output: Optional[Path] = typer.Option(
+        None,
+        help="File to write output to, stdout if not specified. Gzipped output are supported.",
         dir_okay=False,
         writable=True,
     ),
 ) -> None:
-    """Generate OCR insights of the requested type.
-
-    SOURCE can be either:
-    * the path to a JSON file, a (gzipped-)JSONL file, or a directory
-        containing JSON files
-    * a barcode
-    * the '-' character: input is read from stdin and assumed to be JSONL
-
-    Output is JSONL, each line containing the insights for one document.
-    """
-    from typing import TextIO, Union
-
+    """Generate OCR predictions of the requested type."""
     from robotoff.cli import insights
-    from robotoff.prediction.types import PredictionType
     from robotoff.utils import get_logger
 
-    input_: Union[str, TextIO] = sys.stdin if source == "-" else source
-
     get_logger()
-    insights.run_from_ocr_archive(input_, PredictionType[prediction_type], output)
+    insights.run_from_ocr_archive(input_path, prediction_type, output)
 
 
 @app.command()
@@ -147,39 +160,63 @@ def categorize(
 
 @app.command()
 def import_insights(
-    insight_type: Optional[str],
-    server_domain: Optional[str] = None,
-    batch_size: int = 1024,
-    input_: Optional[pathlib.Path] = None,
-    generate_from: Optional[pathlib.Path] = None,
+    prediction_type: Optional[PredictionType] = typer.Option(
+        None,
+        help="Type of the prediction to generate, only needed when --generate-from is used",
+    ),
+    batch_size: int = typer.Option(
+        128,
+        help="Number of insights that are imported in each atomic SQL transaction",
+    ),
+    input_path: Optional[pathlib.Path] = typer.Option(
+        None,
+        help="Input path of the JSONL archive, is incompatible with --generate-from",
+    ),
+    generate_from: Optional[pathlib.Path] = typer.Option(
+        None, help="Input path of the OCR archive, is incompatible with --input-path"
+    ),
 ) -> None:
-    """This command is used to backfill a new insight type on the daily product data dump."""
+    """Import insights from a prediction JSONL archive (with --input-path
+    option), or generate them on the fly from an OCR archive (with
+    --generate-from option)."""
+    import tqdm
+    from more_itertools import chunked
+
     from robotoff import settings
-    from robotoff.cli.insights import generate_from_ocr_archive
-    from robotoff.cli.insights import import_insights as import_insights_
-    from robotoff.cli.insights import insights_iter
-    from robotoff.prediction.types import PredictionType
+    from robotoff.cli.insights import generate_from_ocr_archive, insights_iter
+    from robotoff.insights import importer
+    from robotoff.models import db
     from robotoff.utils import get_logger
 
     logger = get_logger()
-    server_domain = server_domain or settings.OFF_SERVER_DOMAIN
 
     if generate_from is not None:
-        logger.info("Generating and importing insights from {}".format(generate_from))
-        if insight_type is None:
-            sys.exit("Required option: --insight-type")
+        logger.info(f"Generating and importing insights from {generate_from}")
+        if prediction_type is None:
+            sys.exit("Required option: --prediction-type")
 
-        insights = generate_from_ocr_archive(
-            generate_from, PredictionType[insight_type]
-        )
-    elif input_ is not None:
-        logger.info("Importing insights from {}".format(input_))
-        insights = insights_iter(input_)
+        predictions = generate_from_ocr_archive(generate_from, prediction_type)
+    elif input_path is not None:
+        logger.info(f"Importing insights from {input_path}")
+        predictions = insights_iter(input_path)
     else:
-        raise ValueError("--generate-from or --input must be provided")
+        raise ValueError("--generate-from or --input-path must be provided")
 
-    imported = import_insights_(insights, server_domain, batch_size)
-    logger.info("{} insights imported".format(imported))
+    imported = 0
+    with db.connection_context():
+        for prediction_batch in tqdm.tqdm(
+            chunked(predictions, batch_size), desc="prediction batch"
+        ):
+            # Create a new transaction for every batch
+            with db.atomic():
+                batch_imported = importer.import_insights(
+                    prediction_batch,
+                    settings.OFF_SERVER_DOMAIN,
+                )
+                logger.info(f"{batch_imported} insights imported in batch")
+                imported += batch_imported
+
+    logger.info(f"{imported} insights imported")
 
 
 @app.command()
@@ -188,8 +225,8 @@ def refresh_insights(
         None,
         help="Refresh a specific product. If not provided, all products are updated",
     ),
-    server_domain: Optional[str] = typer.Option(
-        None, help="The server domain to use, Open Food Facts by default"
+    batch_size: int = typer.Option(
+        100, help="Number of products to send in a worker tasks"
     ),
 ):
     """Refresh insights based on available predictions.
@@ -197,29 +234,177 @@ def refresh_insights(
     If a `barcode` is provided, only the insights of this product is
     refreshed, otherwise insights of all products are refreshed.
     """
+    import tqdm
+    from more_itertools import chunked
+    from peewee import fn
+
     from robotoff import settings
-    from robotoff.insights.importer import refresh_all_insights
     from robotoff.insights.importer import refresh_insights as refresh_insights_
+    from robotoff.models import Prediction as PredictionModel
+    from robotoff.models import db
     from robotoff.utils import get_logger
+    from robotoff.workers.queues import enqueue_job, low_queue
+    from robotoff.workers.tasks import refresh_insights_job
 
     logger = get_logger()
-    server_domain = server_domain or settings.OFF_SERVER_DOMAIN
 
     if barcode is not None:
         logger.info(f"Refreshing product {barcode}")
-        imported = refresh_insights_(barcode, server_domain)
+        imported = refresh_insights_(barcode, settings.OFF_SERVER_DOMAIN)
+        logger.info(f"Refreshed insights: {imported}")
     else:
-        logger.info("Refreshing insights of all products")
-        imported = refresh_all_insights(server_domain)
+        logger.info("Launching insight refresh on full database")
+        with db:
+            barcodes = [
+                barcode
+                for (barcode,) in PredictionModel.select(
+                    fn.Distinct(PredictionModel.barcode)
+                ).tuples()
+            ]
 
-    logger.info(f"Refreshed insights: {imported}")
+        batches = list(chunked(barcodes, batch_size))
+        confirm = typer.confirm(
+            f"{len(batches)} jobs are going to be launched, confirm?"
+        )
+
+        if not confirm:
+            return
+
+        logger.info("Adding refresh_insights jobs in queue...")
+        for barcode_batch in tqdm.tqdm(batches, desc="barcode batch"):
+            enqueue_job(
+                refresh_insights_job,
+                low_queue,
+                job_kwargs={"result_ttl": 0, "timeout": "5m"},
+                barcodes=barcode_batch,
+                server_domain=settings.OFF_SERVER_DOMAIN,
+            )
+
+
+@app.command()
+def import_images_in_db(
+    batch_size: int = typer.Option(
+        500, help="Number of items to send in a worker tasks"
+    ),
+):
+    """Make sure that every image available in MongoDB is saved in `image`
+    table."""
+    import tqdm
+    from more_itertools import chunked
+
+    from robotoff import settings
+    from robotoff.models import ImageModel, db
+    from robotoff.off import generate_image_path
+    from robotoff.products import get_product_store
+    from robotoff.utils import get_logger
+    from robotoff.workers.queues import enqueue_job, low_queue
+    from robotoff.workers.tasks.import_image import save_image_job
+
+    logger = get_logger()
+
+    with db:
+        logger.info("Fetching existing images in DB...")
+        existing_images = set(
+            ImageModel.select(ImageModel.barcode, ImageModel.image_id).tuples()
+        )
+
+    store = get_product_store()
+    to_add = []
+    for product in tqdm.tqdm(
+        store.iter_product(projection=["images", "code"]), desc="product"
+    ):
+        barcode = product.barcode
+        for image_id in (id_ for id_ in product.images.keys() if id_.isdigit()):
+            if (barcode, image_id) not in existing_images:
+                to_add.append((barcode, generate_image_path(barcode, image_id)))
+
+    batches = list(chunked(to_add, batch_size))
+    if typer.confirm(
+        f"{len(batches)} add image jobs are going to be launched, confirm?"
+    ):
+        for batch in tqdm.tqdm(batches, desc="job"):
+            enqueue_job(
+                save_image_job,
+                low_queue,
+                job_kwargs={"result_ttl": 0},
+                batch=batch,
+                server_domain=settings.OFF_SERVER_DOMAIN,
+            )
+
+
+@app.command()
+def run_object_detection_model(
+    model_name: ObjectDetectionModel = typer.Argument(
+        ..., help="Name of the object detection model"
+    ),
+    limit: Optional[int] = typer.Option(None, help="Maximum numbers of job to launch"),
+):
+    """Launch object detection model jobs on all missing images (images
+    without an ImagePrediction item for this model) in DB."""
+    from typing import Callable
+
+    import tqdm
+    from peewee import JOIN
+
+    from robotoff import settings
+    from robotoff.models import ImageModel, ImagePrediction, db
+    from robotoff.off import generate_image_url
+    from robotoff.workers.queues import enqueue_job, low_queue
+    from robotoff.workers.tasks.import_image import (
+        run_logo_object_detection,
+        run_nutriscore_object_detection,
+        run_nutrition_table_object_detection,
+    )
+
+    kwargs = {}
+    if model_name == ObjectDetectionModel.universal_logo_detector:
+        func: Callable = run_logo_object_detection
+        kwargs["process_logos"] = False
+    elif model_name == ObjectDetectionModel.nutrition_table:
+        func = run_nutrition_table_object_detection
+    else:
+        func = run_nutriscore_object_detection
+
+    with db:
+        query = (
+            ImageModel.select(ImageModel.barcode, ImageModel.id)
+            .join(
+                ImagePrediction,
+                JOIN.LEFT_OUTER,
+                on=(
+                    (ImagePrediction.image_id == ImageModel.id)
+                    & (ImagePrediction.model_name == model_name)
+                ),
+            )
+            .where(ImagePrediction.model_name.is_null())
+            .tuples()
+        )
+        if limit:
+            query = query.limit(limit)
+        missing_items = list(query)
+
+    if limit:
+        missing_items = missing_items[:limit]
+
+    if typer.confirm(f"{len(missing_items)} jobs are going to be launched, confirm?"):
+        for barcode, image_id in tqdm.tqdm(missing_items, desc="image"):
+            image_url = generate_image_url(barcode, image_id)
+            enqueue_job(
+                func,
+                low_queue,
+                job_kwargs={"result_ttl": 0},
+                barcode=barcode,
+                image_url=image_url,
+                server_domain=settings.OFF_SERVER_DOMAIN,
+                **kwargs,
+            )
 
 
 @app.command()
 def init_elasticsearch(
     load_index: bool = False,
     load_data: bool = True,
-    to_load: Optional[List[str]] = None,
+    to_load: Optional[list[str]] = None,
 ) -> None:
     """
     This command is used for manual insertion of the Elasticsearch data and/or indexes
