@@ -1,6 +1,6 @@
 import dataclasses
 import pathlib
-from typing import Dict, List, Optional, Tuple
+from typing import Optional
 
 import cachetools
 import grpc
@@ -10,6 +10,7 @@ from tritonclient.grpc import service_pb2, service_pb2_grpc
 
 from robotoff import settings
 from robotoff.prediction.object_detection.utils import visualization_utils as vis_util
+from robotoff.types import ObjectDetectionModel
 from robotoff.utils import get_logger, text_file_iter
 from robotoff.utils.types import JSONType
 
@@ -18,9 +19,16 @@ logger = get_logger(__name__)
 LABEL_NAMES_FILENAME = "labels.txt"
 
 
+OBJECT_DETECTION_MODEL_VERSION = {
+    ObjectDetectionModel.nutriscore: "tf-nutriscore-1.0",
+    ObjectDetectionModel.nutrition_table: "tf-nutrition-table-1.0",
+    ObjectDetectionModel.universal_logo_detector: "tf-universal-logo-detector-1.0",
+}
+
+
 @dataclasses.dataclass
 class ObjectDetectionResult:
-    bounding_box: Tuple
+    bounding_box: tuple
     score: float
     label: str
 
@@ -31,11 +39,11 @@ class ObjectDetectionRawResult:
     detection_boxes: np.ndarray
     detection_scores: np.ndarray
     detection_classes: np.ndarray
-    label_names: List[str]
+    label_names: list[str]
     detection_masks: Optional[np.ndarray] = None
     boxed_image: Optional[Image.Image] = None
 
-    def select(self, threshold: Optional[float] = None) -> List[ObjectDetectionResult]:
+    def select(self, threshold: Optional[float] = None) -> list[ObjectDetectionResult]:
         if threshold is None:
             threshold = 0.5
 
@@ -60,7 +68,7 @@ class ObjectDetectionRawResult:
 
         return results
 
-    def to_json(self, threshold: Optional[float] = None) -> List[JSONType]:
+    def to_json(self, threshold: Optional[float] = None) -> list[JSONType]:
         return [dataclasses.asdict(r) for r in self.select(threshold)]
 
 
@@ -88,7 +96,7 @@ def add_boxes_and_labels(image_array: np.ndarray, raw_result: ObjectDetectionRaw
     raw_result.boxed_image = image_with_boxes
 
 
-def resize_image(image: Image.Image, max_size: Tuple[int, int]) -> Image.Image:
+def resize_image(image: Image.Image, max_size: tuple[int, int]) -> Image.Image:
     width, height = image.size
     max_width, max_height = max_size
 
@@ -107,7 +115,7 @@ def get_triton_inference_stub():
 
 
 class RemoteModel:
-    def __init__(self, name: str, label_names: List[str]):
+    def __init__(self, name: str, label_names: list[str]):
         self.name: str = name
         self.label_names = label_names
 
@@ -189,11 +197,11 @@ class RemoteModel:
 
 
 class ObjectDetectionModelRegistry:
-    models: Dict[str, RemoteModel] = {}
+    models: dict[str, RemoteModel] = {}
     _loaded = False
 
     @classmethod
-    def get_available_models(cls) -> List[str]:
+    def get_available_models(cls) -> list[str]:
         cls.load_all()
         return list(cls.models.keys())
 
@@ -201,13 +209,14 @@ class ObjectDetectionModelRegistry:
     def load_all(cls):
         if cls._loaded:
             return
-        for model_name in settings.OBJECT_DETECTION_MODEL_VERSION:
+        for model in ObjectDetectionModel:
+            model_name = model.value
             file_path = settings.MODELS_DIR / model_name
             if file_path.is_dir():
-                logger.info(f"Model '{model_name}' found")
+                logger.info("Model %s found", model_name)
                 cls.models[model_name] = cls.load(model_name, file_path)
             else:
-                logger.info(f"Missing model: '{model_name}'")
+                logger.info("Missing model: %s", model_name)
         cls._loaded = True
 
     @classmethod
