@@ -2,6 +2,7 @@ import datetime
 import pathlib
 from typing import Optional
 
+from requests.exceptions import ConnectionError as RequestConnectionError
 from requests.exceptions import HTTPError, Timeout
 
 from robotoff.insights.extraction import (
@@ -286,10 +287,10 @@ def run_nutriscore_object_detection(barcode: str, image_url: str, server_domain:
             value_tag=label_tag,
             automatic_processing=False,
             server_domain=server_domain,
+            predictor="nutriscore",
             data={
                 "confidence": score,
                 "bounding_box": result["bounding_box"],
-                "model": ObjectDetectionModel.nutriscore.value,
             },
         )
         import_insights([prediction], server_domain)
@@ -370,22 +371,14 @@ def process_created_logos(image_prediction_id: int, server_domain: str):
 
         try:
             add_logos_to_ann(image_instance, logos)
-        except (HTTPError, Timeout) as e:
-            logger.info(
-                "Request error during logo addition to ANN: %s, %s",
-                type(e).__name__,
-                e,
-            )
+        except (RequestConnectionError, HTTPError, Timeout) as e:
+            logger.info("Request error during logo addition to ANN", exc_info=e)
             return
 
         try:
             save_nearest_neighbors(logos)
-        except (HTTPError, Timeout) as e:
-            logger.info(
-                "Request error during ANN batch query: %s, %s",
-                type(e).__name__,
-                e,
-            )
+        except (RequestConnectionError, HTTPError, Timeout) as e:
+            logger.info("Request error during ANN batch query", exc_info=e)
             return
 
         thresholds = get_logo_confidence_thresholds()
