@@ -7,6 +7,7 @@ from robotoff.off import ServerType, get_server_type
 from robotoff.prediction.category.matcher import predict as predict_category_matcher
 from robotoff.prediction.category.neural.category_classifier import CategoryClassifier
 from robotoff.products import get_product
+from robotoff.redis import Lock, LockedResourceException
 from robotoff.taxonomy import TaxonomyType, get_taxonomy
 from robotoff.utils import get_logger
 from robotoff.utils.types import JSONType
@@ -15,21 +16,40 @@ logger = get_logger(__name__)
 
 
 @with_db
-def update_insights(barcode: str, server_domain: str):
-    # Sleep 10s to let the OFF update request that triggered the webhook call
-    # to finish
-    logger.info(f"Running `update_insights` for product {barcode} ({server_domain})")
+def update_insights_job(barcode: str, server_domain: str):
+    """This job is triggered by the webhook API, when product information has
+    been updated.
 
-    product_dict = get_product(barcode)
+    When a product is updated, Robotoff will:
 
-    if product_dict is None:
-        logger.warning("Updated product does not exist: %s", barcode)
-        return
+    1. Generate new predictions related to the product's category and name.
+    2. Regenerate all insights from the product associated predictions.
+    """
+    logger.info("Running `update_insights` for product %s (%s)", barcode, server_domain)
 
-    updated_product_predict_insights(barcode, product_dict, server_domain)
-    logger.info("Refreshing insights...")
-    imported = refresh_insights(barcode, server_domain)
-    logger.info(f"{imported} insights created after refresh")
+    try:
+        with Lock(
+            name=f"robotoff:product_update_job:{barcode}", expire=300, timeout=10
+        ):
+            # We handle concurrency thanks to the lock as the task will fetch
+            # product from MongoDB at the time it runs, it's not worth
+            # reprocessing with another task arriving concurrently.
+            # The expire is there only in case the lock is not released
+            # (process killed)
+            product_dict = get_product(barcode)
+
+            if product_dict is None:
+                logger.warning("Updated product does not exist: %s", barcode)
+                return
+
+            updated_product_predict_insights(barcode, product_dict, server_domain)
+            logger.info("Refreshing insights...")
+            imported = refresh_insights(barcode, server_domain)
+            logger.info("%s insights created after refresh", imported)
+    except LockedResourceException:
+        logger.info(
+            f"Couldn't acquire product_update lock, skipping product_update for product {barcode}"
+        )
 
 
 def add_category_insight(barcode: str, product: JSONType, server_domain: str) -> bool:
@@ -65,7 +85,7 @@ def add_category_insight(barcode: str, product: JSONType, server_domain: str) ->
         prediction.barcode = barcode
 
     imported = import_insights(product_predictions, server_domain)
-    logger.info(f"{imported} category insight imported for product {barcode}")
+    logger.info("%s category insight imported for product %s", imported, barcode)
 
     return bool(imported)
 
@@ -82,7 +102,7 @@ def updated_product_predict_insights(
     logger.info("Generating predictions from product name...")
     predictions_all = get_predictions_from_product_name(barcode, product_name)
     imported = import_insights(predictions_all, server_domain)
-    logger.info(f"{imported} insights imported for product {barcode}")
+    logger.info("%s insights imported for product %s", imported, barcode)
 
     if imported:
         updated = True
